/*******************************************************************************
* File Name: DPWM.c  
* Version 3.0
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DPWM.h"

uint8 DPWM_initVar = 0u;


/*******************************************************************************
* Function Name: DPWM_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
* Global variables:
*  DPWM_initVar: Is modified when this function is called for the 
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void DPWM_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(DPWM_initVar == 0u)
    {
        DPWM_Init();
        DPWM_initVar = 1u;
    }
    DPWM_Enable();

}


/*******************************************************************************
* Function Name: DPWM_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  DPWM_Start().
*
* Parameters:  
*  None
*
* Return: 
*  None
*
*******************************************************************************/
void DPWM_Init(void) 
{
    #if (DPWM_UsingFixedFunction || DPWM_UseControl)
        uint8 ctrl;
    #endif /* (DPWM_UsingFixedFunction || DPWM_UseControl) */
    
    #if(!DPWM_UsingFixedFunction) 
        #if(DPWM_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 DPWM_interruptState;
        #endif /* (DPWM_UseStatus) */
    #endif /* (!DPWM_UsingFixedFunction) */
    
    #if (DPWM_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        DPWM_CONTROL |= DPWM_CFG0_MODE;
        #if (DPWM_DeadBand2_4)
            DPWM_CONTROL |= DPWM_CFG0_DB;
        #endif /* (DPWM_DeadBand2_4) */
                
        ctrl = DPWM_CONTROL3 & ((uint8 )(~DPWM_CTRL_CMPMODE1_MASK));
        DPWM_CONTROL3 = ctrl | DPWM_DEFAULT_COMPARE1_MODE;
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        DPWM_RT1 &= ((uint8)(~DPWM_RT1_MASK));
        DPWM_RT1 |= DPWM_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        DPWM_RT1 &= ((uint8)(~DPWM_SYNCDSI_MASK));
        DPWM_RT1 |= DPWM_SYNCDSI_EN;
       
    #elif (DPWM_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = DPWM_CONTROL & ((uint8)(~DPWM_CTRL_CMPMODE2_MASK)) & ((uint8)(~DPWM_CTRL_CMPMODE1_MASK));
        DPWM_CONTROL = ctrl | DPWM_DEFAULT_COMPARE2_MODE | 
                                   DPWM_DEFAULT_COMPARE1_MODE;
    #endif /* (DPWM_UsingFixedFunction) */
        
    #if (!DPWM_UsingFixedFunction)
        #if (DPWM_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            DPWM_AUX_CONTROLDP0 |= (DPWM_AUX_CTRL_FIFO0_CLR);
        #else /* (DPWM_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            DPWM_AUX_CONTROLDP0 |= (DPWM_AUX_CTRL_FIFO0_CLR);
            DPWM_AUX_CONTROLDP1 |= (DPWM_AUX_CTRL_FIFO0_CLR);
        #endif /* (DPWM_Resolution == 8) */

        DPWM_WriteCounter(DPWM_INIT_PERIOD_VALUE);
    #endif /* (!DPWM_UsingFixedFunction) */
        
    DPWM_WritePeriod(DPWM_INIT_PERIOD_VALUE);

        #if (DPWM_UseOneCompareMode)
            DPWM_WriteCompare(DPWM_INIT_COMPARE_VALUE1);
        #else
            DPWM_WriteCompare1(DPWM_INIT_COMPARE_VALUE1);
            DPWM_WriteCompare2(DPWM_INIT_COMPARE_VALUE2);
        #endif /* (DPWM_UseOneCompareMode) */
        
        #if (DPWM_KillModeMinTime)
            DPWM_WriteKillTime(DPWM_MinimumKillTime);
        #endif /* (DPWM_KillModeMinTime) */
        
        #if (DPWM_DeadBandUsed)
            DPWM_WriteDeadTime(DPWM_INIT_DEAD_TIME);
        #endif /* (DPWM_DeadBandUsed) */

    #if (DPWM_UseStatus || DPWM_UsingFixedFunction)
        DPWM_SetInterruptMode(DPWM_INIT_INTERRUPTS_MODE);
    #endif /* (DPWM_UseStatus || DPWM_UsingFixedFunction) */
        
    #if (DPWM_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        DPWM_GLOBAL_ENABLE |= DPWM_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        DPWM_CONTROL2 |= DPWM_CTRL2_IRQ_SEL;
    #else
        #if(DPWM_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            DPWM_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            DPWM_STATUS_AUX_CTRL |= DPWM_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(DPWM_interruptState);
            
            /* Clear the FIFO to enable the DPWM_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            DPWM_ClearFIFO();
        #endif /* (DPWM_UseStatus) */
    #endif /* (DPWM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DPWM_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
*******************************************************************************/
void DPWM_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (DPWM_UsingFixedFunction)
        DPWM_GLOBAL_ENABLE |= DPWM_BLOCK_EN_MASK;
        DPWM_GLOBAL_STBY_ENABLE |= DPWM_BLOCK_STBY_EN_MASK;
    #endif /* (DPWM_UsingFixedFunction) */
    
    /* Enable the PWM from the control register  */
    #if (DPWM_UseControl || DPWM_UsingFixedFunction)
        DPWM_CONTROL |= DPWM_CTRL_ENABLE;
    #endif /* (DPWM_UseControl || DPWM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DPWM_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
*******************************************************************************/
void DPWM_Stop(void) 
{
    #if (DPWM_UseControl || DPWM_UsingFixedFunction)
        DPWM_CONTROL &= ((uint8)(~DPWM_CTRL_ENABLE));
    #endif /* (DPWM_UseControl || DPWM_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (DPWM_UsingFixedFunction)
        DPWM_GLOBAL_ENABLE &= ((uint8)(~DPWM_BLOCK_EN_MASK));
        DPWM_GLOBAL_STBY_ENABLE &= ((uint8)(~DPWM_BLOCK_STBY_EN_MASK));
    #endif /* (DPWM_UsingFixedFunction) */
}


#if (DPWM_UseOneCompareMode)
	#if (DPWM_CompareMode1SW)


		/*******************************************************************************
		* Function Name: DPWM_SetCompareMode
		********************************************************************************
		* 
		* Summary:
		*  This function writes the Compare Mode for the pwm output when in Dither mode,
		*  Center Align Mode or One Output Mode.
		*
		* Parameters:
		*  comparemode:  The new compare mode for the PWM output. Use the compare types
		*                defined in the H file as input arguments.
		*
		* Return:
		*  None
		*
		*******************************************************************************/
		void DPWM_SetCompareMode(uint8 comparemode) 
		{
		    #if(DPWM_UsingFixedFunction)
            
                #if(0 != DPWM_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemodemasked = ((uint8)((uint8)comparemode << DPWM_CTRL_CMPMODE1_SHIFT));
                #else
                    uint8 comparemodemasked = comparemode;
                #endif /* (0 != DPWM_CTRL_CMPMODE1_SHIFT) */
            
	            DPWM_CONTROL3 &= ((uint8)(~DPWM_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
	            DPWM_CONTROL3 |= comparemodemasked;     
		                
		    #elif (DPWM_UseControl)
		        
                #if(0 != DPWM_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemode1masked = ((uint8)((uint8)comparemode << DPWM_CTRL_CMPMODE1_SHIFT)) & 
    		                                    DPWM_CTRL_CMPMODE1_MASK;
                #else
                    uint8 comparemode1masked = comparemode & DPWM_CTRL_CMPMODE1_MASK;                
                #endif /* (0 != DPWM_CTRL_CMPMODE1_SHIFT) */
                
                #if(0 != DPWM_CTRL_CMPMODE2_SHIFT)                            
    		        uint8 comparemode2masked = ((uint8)((uint8)comparemode << DPWM_CTRL_CMPMODE2_SHIFT)) & 
    		                                   DPWM_CTRL_CMPMODE2_MASK;
                #else
    		        uint8 comparemode2masked = comparemode & DPWM_CTRL_CMPMODE2_MASK;                
                #endif /* (0 != DPWM_CTRL_CMPMODE2_SHIFT) */
                
		        /*Clear existing mode */
		        DPWM_CONTROL &= ((uint8)(~(DPWM_CTRL_CMPMODE1_MASK | DPWM_CTRL_CMPMODE2_MASK))); 
		        DPWM_CONTROL |= (comparemode1masked | comparemode2masked);
		        
		    #else
		        uint8 temp = comparemode;
		    #endif /* (DPWM_UsingFixedFunction) */
		}
	#endif /* DPWM_CompareMode1SW */

#else /* UseOneCompareMode */

	#if (DPWM_CompareMode1SW)


		/*******************************************************************************
		* Function Name: DPWM_SetCompareMode1
		********************************************************************************
		* 
		* Summary:
		*  This function writes the Compare Mode for the pwm or pwm1 output
		*
		* Parameters:  
		*  comparemode:  The new compare mode for the PWM output. Use the compare types
		*                defined in the H file as input arguments.
		*
		* Return: 
		*  None
		*
		*******************************************************************************/
		void DPWM_SetCompareMode1(uint8 comparemode) 
		{
		    #if(0 != DPWM_CTRL_CMPMODE1_SHIFT)
                uint8 comparemodemasked = ((uint8)((uint8)comparemode << DPWM_CTRL_CMPMODE1_SHIFT)) & 
    		                               DPWM_CTRL_CMPMODE1_MASK;
		    #else
                uint8 comparemodemasked = comparemode & DPWM_CTRL_CMPMODE1_MASK;                
            #endif /* (0 != DPWM_CTRL_CMPMODE1_SHIFT) */
                   
		    #if (DPWM_UseControl)
		        DPWM_CONTROL &= ((uint8)(~DPWM_CTRL_CMPMODE1_MASK)); /*Clear existing mode */
		        DPWM_CONTROL |= comparemodemasked;
		    #endif /* (DPWM_UseControl) */
		}
	#endif /* DPWM_CompareMode1SW */

#if (DPWM_CompareMode2SW)


    /*******************************************************************************
    * Function Name: DPWM_SetCompareMode2
    ********************************************************************************
    * 
    * Summary:
    *  This function writes the Compare Mode for the pwm or pwm2 output
    *
    * Parameters:  
    *  comparemode:  The new compare mode for the PWM output. Use the compare types
    *                defined in the H file as input arguments.
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void DPWM_SetCompareMode2(uint8 comparemode) 
    {

        #if(0 != DPWM_CTRL_CMPMODE2_SHIFT)
            uint8 comparemodemasked = ((uint8)((uint8)comparemode << DPWM_CTRL_CMPMODE2_SHIFT)) & 
                                                 DPWM_CTRL_CMPMODE2_MASK;
        #else
            uint8 comparemodemasked = comparemode & DPWM_CTRL_CMPMODE2_MASK;            
        #endif /* (0 != DPWM_CTRL_CMPMODE2_SHIFT) */
        
        #if (DPWM_UseControl)
            DPWM_CONTROL &= ((uint8)(~DPWM_CTRL_CMPMODE2_MASK)); /*Clear existing mode */
            DPWM_CONTROL |= comparemodemasked;
        #endif /* (DPWM_UseControl) */
    }
    #endif /*DPWM_CompareMode2SW */

#endif /* UseOneCompareMode */


#if (!DPWM_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: DPWM_WriteCounter
    ********************************************************************************
    * 
    * Summary:
    *  Writes a new counter value directly to the counter register. This will be 
    *  implemented for that currently running period and only that period. This API 
    *  is valid only for UDB implementation and not available for fixed function 
    *  PWM implementation.    
    *
    * Parameters:  
    *  counter:  The period new period counter value.
    *
    * Return: 
    *  None
    *
    * Side Effects: 
    *  The PWM Period will be reloaded when a counter value will be a zero
    *
    *******************************************************************************/
    void DPWM_WriteCounter(uint16 counter) \
                                       
    {
        CY_SET_REG16(DPWM_COUNTER_LSB_PTR, counter);
    }


    /*******************************************************************************
    * Function Name: DPWM_ReadCounter
    ********************************************************************************
    * 
    * Summary:
    *  This function returns the current value of the counter.  It doesn't matter
    *  if the counter is enabled or running.
    *
    * Parameters:  
    *  None  
    *
    * Return: 
    *  The current value of the counter.
    *
    *******************************************************************************/
    uint16 DPWM_ReadCounter(void) 
    {
        /* Force capture by reading Accumulator */
        /* Must first do a software capture to be able to read the counter */
        /* It is up to the user code to make sure there isn't already captured data in the FIFO */
        (void)DPWM_COUNTERCAP_LSB;
        
        /* Read the data from the FIFO (or capture register for Fixed Function)*/
        return (CY_GET_REG16(DPWM_CAPTURE_LSB_PTR));
    }

        #if (DPWM_UseStatus)


            /*******************************************************************************
            * Function Name: DPWM_ClearFIFO
            ********************************************************************************
            * 
            * Summary:
            *  This function clears all capture data from the capture FIFO
            *
            * Parameters:  
            *  None
            *
            * Return: 
            *  None
            *
            *******************************************************************************/
            void DPWM_ClearFIFO(void) 
            {
                while(0u != (DPWM_ReadStatusRegister() & DPWM_STATUS_FIFONEMPTY))
                {
                    (void)DPWM_ReadCapture();
                }
            }

        #endif /* DPWM_UseStatus */

#endif /* !DPWM_UsingFixedFunction */


/*******************************************************************************
* Function Name: DPWM_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  None
*
*******************************************************************************/
void DPWM_WritePeriod(uint16 period) 
{
    #if(DPWM_UsingFixedFunction)
        CY_SET_REG16(DPWM_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG16(DPWM_PERIOD_LSB_PTR, period);
    #endif /* (DPWM_UsingFixedFunction) */
}

#if (DPWM_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: DPWM_WriteCompare
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare1 value when the PWM is in Dither
    *  mode. The compare output will reflect the new value on the next UDB clock. 
    *  The compare output will be driven high when the present counter value is 
    *  compared to the compare value based on the compare mode defined in 
    *  Dither Mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    * Side Effects:
    *  This function is only available if the PWM mode parameter is set to
    *  Dither Mode, Center Aligned Mode or One Output Mode
    *
    *******************************************************************************/
    void DPWM_WriteCompare(uint16 compare) \
                                       
    {	
		#if(DPWM_UsingFixedFunction)
			CY_SET_REG16(DPWM_COMPARE1_LSB_PTR, (uint16)compare);
		#else
	        CY_SET_REG16(DPWM_COMPARE1_LSB_PTR, compare);	
		#endif /* (DPWM_UsingFixedFunction) */
        
        #if (DPWM_PWMMode == DPWM__B_PWM__DITHER)
            #if(DPWM_UsingFixedFunction)
    			CY_SET_REG16(DPWM_COMPARE2_LSB_PTR, (uint16)(compare + 1u));
    		#else
    	        CY_SET_REG16(DPWM_COMPARE2_LSB_PTR, (compare + 1u));	
    		#endif /* (DPWM_UsingFixedFunction) */
        #endif /* (DPWM_PWMMode == DPWM__B_PWM__DITHER) */
    }


#else


    /*******************************************************************************
    * Function Name: DPWM_WriteCompare1
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare1 value.  The compare output will 
    *  reflect the new value on the next UDB clock.  The compare output will be 
    *  driven high when the present counter value is less than or less than or 
    *  equal to the compare register, depending on the mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void DPWM_WriteCompare1(uint16 compare) \
                                        
    {
        #if(DPWM_UsingFixedFunction)
            CY_SET_REG16(DPWM_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG16(DPWM_COMPARE1_LSB_PTR, compare);
        #endif /* (DPWM_UsingFixedFunction) */
    }


    /*******************************************************************************
    * Function Name: DPWM_WriteCompare2
    ********************************************************************************
    * 
    * Summary:
    *  This funtion is used to change the compare value, for compare1 output.  
    *  The compare output will reflect the new value on the next UDB clock.  
    *  The compare output will be driven high when the present counter value is 
    *  less than or less than or equal to the compare register, depending on the 
    *  mode.
    *
    * Parameters:  
    *  compare:  New compare value.  
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void DPWM_WriteCompare2(uint16 compare) \
                                        
    {
        #if(DPWM_UsingFixedFunction)
            CY_SET_REG16(DPWM_COMPARE2_LSB_PTR, compare);
        #else
            CY_SET_REG16(DPWM_COMPARE2_LSB_PTR, compare);
        #endif /* (DPWM_UsingFixedFunction) */
    }
#endif /* UseOneCompareMode */

#if (DPWM_DeadBandUsed)


    /*******************************************************************************
    * Function Name: DPWM_WriteDeadTime
    ********************************************************************************
    * 
    * Summary:
    *  This function writes the dead-band counts to the corresponding register
    *
    * Parameters:  
    *  deadtime:  Number of counts for dead time 
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void DPWM_WriteDeadTime(uint8 deadtime) 
    {
        /* If using the Dead Band 1-255 mode then just write the register */
        #if(!DPWM_DeadBand2_4)
            CY_SET_REG8(DPWM_DEADBAND_COUNT_PTR, deadtime);
        #else
            /* Otherwise the data has to be masked and offset */        
            /* Clear existing data */
            DPWM_DEADBAND_COUNT &= ((uint8)(~DPWM_DEADBAND_COUNT_MASK));
            
            /* Set new dead time */
            #if(DPWM_DEADBAND_COUNT_SHIFT)        
                DPWM_DEADBAND_COUNT |= ((uint8)((uint8)deadtime << DPWM_DEADBAND_COUNT_SHIFT)) & 
                                                    DPWM_DEADBAND_COUNT_MASK;
            #else
                DPWM_DEADBAND_COUNT |= deadtime & DPWM_DEADBAND_COUNT_MASK;        
            #endif /* (DPWM_DEADBAND_COUNT_SHIFT) */
        
        #endif /* (!DPWM_DeadBand2_4) */
    }


    /*******************************************************************************
    * Function Name: DPWM_ReadDeadTime
    ********************************************************************************
    * 
    * Summary:
    *  This function reads the dead-band counts from the corresponding register
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  Dead Band Counts
    *
    *******************************************************************************/
    uint8 DPWM_ReadDeadTime(void) 
    {
        /* If using the Dead Band 1-255 mode then just read the register */
        #if(!DPWM_DeadBand2_4)
            return (CY_GET_REG8(DPWM_DEADBAND_COUNT_PTR));
        #else
        
            /* Otherwise the data has to be masked and offset */
            #if(DPWM_DEADBAND_COUNT_SHIFT)      
                return ((uint8)(((uint8)(DPWM_DEADBAND_COUNT & DPWM_DEADBAND_COUNT_MASK)) >> 
                                                                           DPWM_DEADBAND_COUNT_SHIFT));
            #else
                return (DPWM_DEADBAND_COUNT & DPWM_DEADBAND_COUNT_MASK);
            #endif /* (DPWM_DEADBAND_COUNT_SHIFT) */
        #endif /* (!DPWM_DeadBand2_4) */
    }
#endif /* DeadBandUsed */

#if (DPWM_UseStatus || DPWM_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: DPWM_SetInterruptMode
    ********************************************************************************
    * 
    * Summary:
    *  This function configures the interrupts mask control of theinterrupt 
    *  source status register.
    *
    * Parameters:  
    *  uint8 interruptMode: Bit field containing the interrupt sources enabled 
    *
    * Return: 
    *  None
    *
    *******************************************************************************/
    void DPWM_SetInterruptMode(uint8 interruptMode)  
    {
    	CY_SET_REG8(DPWM_STATUS_MASK_PTR, interruptMode);
    }


    /*******************************************************************************
    * Function Name: DPWM_ReadStatusRegister
    ********************************************************************************
    * 
    * Summary:
    *  This function returns the current state of the status register. 
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8 : Current status register value. The status register bits are:
    *  [7:6] : Unused(0)
    *  [5]   : Kill event output
    *  [4]   : FIFO not empty
    *  [3]   : FIFO full
    *  [2]   : Terminal count
    *  [1]   : Compare output 2
    *  [0]   : Compare output 1
    *
    *******************************************************************************/
    uint8 DPWM_ReadStatusRegister(void)   
    {
    	uint8 result;
    	
    	result = CY_GET_REG8(DPWM_STATUS_PTR);
    	return (result);
    }

#endif /* (DPWM_UseStatus || DPWM_UsingFixedFunction) */


#if (DPWM_UseControl)


    /*******************************************************************************
    * Function Name: DPWM_ReadControlRegister
    ********************************************************************************
    * 
    * Summary:
    *  Returns the current state of the control register. This API is available 
    *  only if the control register is not removed.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  uint8 : Current control register value
    *
    *******************************************************************************/    
    uint8 DPWM_ReadControlRegister(void) 
    {
    	uint8 result;
    	
    	result = CY_GET_REG8(DPWM_CONTROL_PTR);
    	return (result);
    }


    /*******************************************************************************
    * Function Name: DPWM_WriteControlRegister
    ********************************************************************************
    * 
    * Summary:
    *  Sets the bit field of the control register. This API is available only if 
    *  the control register is not removed.
    *
    * Parameters:  
    *  uint8 control: Control register bit field, The status register bits are:
    *  [7]   : PWM Enable
    *  [6]   : Reset
    *  [5:3] : Compare Mode2
    *  [2:0] : Compare Mode2
    *
    * Return: 
    *  None
    *
    *******************************************************************************/  
    void DPWM_WriteControlRegister(uint8 control) 
    {
    	CY_SET_REG8(DPWM_CONTROL_PTR, control);
    }
	
#endif /* (DPWM_UseControl) */


#if (!DPWM_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: DPWM_ReadCapture
    ********************************************************************************
    * 
    * Summary:
    *  Reads the capture value from the capture FIFO.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: The current capture value
    *
    *******************************************************************************/  
    uint16 DPWM_ReadCapture(void)  
    {
    	return (CY_GET_REG16(DPWM_CAPTURE_LSB_PTR));
    }
	
#endif /* (!DPWM_UsingFixedFunction) */


#if (DPWM_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: DPWM_ReadCompare
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare output when the PWM Mode parameter is 
    *  set to Dither mode, Center Aligned mode, or One Output mode.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value
    *
    *******************************************************************************/  
    uint16 DPWM_ReadCompare(void)  
    {
		#if(DPWM_UsingFixedFunction)
            return ((uint16)CY_GET_REG16(DPWM_COMPARE1_LSB_PTR));
        #else
            return (CY_GET_REG16(DPWM_COMPARE1_LSB_PTR));
        #endif /* (DPWM_UsingFixedFunction) */
    }

#else


    /*******************************************************************************
    * Function Name: DPWM_ReadCompare1
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare1 output.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/  
    uint16 DPWM_ReadCompare1(void) 
    {
		return (CY_GET_REG16(DPWM_COMPARE1_LSB_PTR));
    }


    /*******************************************************************************
    * Function Name: DPWM_ReadCompare2
    ********************************************************************************
    * 
    * Summary:
    *  Reads the compare value for the compare2 output.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/  
    uint16 DPWM_ReadCompare2(void)  
    {
		return (CY_GET_REG16(DPWM_COMPARE2_LSB_PTR));
    }

#endif /* (DPWM_UseOneCompareMode) */


/*******************************************************************************
* Function Name: DPWM_ReadPeriod
********************************************************************************
* 
* Summary:
*  Reads the period value used by the PWM hardware.
*
* Parameters:  
*  None
*
* Return: 
*  uint8/16: Period value
*
*******************************************************************************/ 
uint16 DPWM_ReadPeriod(void) 
{
	#if(DPWM_UsingFixedFunction)
        return ((uint16)CY_GET_REG16(DPWM_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG16(DPWM_PERIOD_LSB_PTR));
    #endif /* (DPWM_UsingFixedFunction) */
}

#if ( DPWM_KillModeMinTime)


    /*******************************************************************************
    * Function Name: DPWM_WriteKillTime
    ********************************************************************************
    * 
    * Summary:
    *  Writes the kill time value used by the hardware when the Kill Mode 
    *  is set to Minimum Time.
    *
    * Parameters:  
    *  uint8: Minimum Time kill counts
    *
    * Return: 
    *  None
    *
    *******************************************************************************/ 
    void DPWM_WriteKillTime(uint8 killtime) 
    {
    	CY_SET_REG8(DPWM_KILLMODEMINTIME_PTR, killtime);
    }


    /*******************************************************************************
    * Function Name: DPWM_ReadKillTime
    ********************************************************************************
    * 
    * Summary:
    *  Reads the kill time value used by the hardware when the Kill Mode is set 
    *  to Minimum Time.
    *
    * Parameters:  
    *  None
    *
    * Return: 
    *  uint8: The current Minimum Time kill counts
    *
    *******************************************************************************/ 
    uint8 DPWM_ReadKillTime(void) 
    {
    	return (CY_GET_REG8(DPWM_KILLMODEMINTIME_PTR));
    }

#endif /* ( DPWM_KillModeMinTime) */

/* [] END OF FILE */
