/*******************************************************************************
* File Name: DPWM_PM.c
* Version 3.0
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "DPWM.h"

static DPWM_backupStruct DPWM_backup;


/*******************************************************************************
* Function Name: DPWM_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  DPWM_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void DPWM_SaveConfig(void) 
{
    
    #if(!DPWM_UsingFixedFunction)
        #if(!DPWM_PWMModeIsCenterAligned)
            DPWM_backup.PWMPeriod = DPWM_ReadPeriod();
        #endif /* (!DPWM_PWMModeIsCenterAligned) */
        DPWM_backup.PWMUdb = DPWM_ReadCounter();
        #if (DPWM_UseStatus)
            DPWM_backup.InterruptMaskValue = DPWM_STATUS_MASK;
        #endif /* (DPWM_UseStatus) */
        
        #if(DPWM_DeadBandMode == DPWM__B_PWM__DBM_256_CLOCKS || \
            DPWM_DeadBandMode == DPWM__B_PWM__DBM_2_4_CLOCKS)
            DPWM_backup.PWMdeadBandValue = DPWM_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */
        
        #if(DPWM_KillModeMinTime)
             DPWM_backup.PWMKillCounterPeriod = DPWM_ReadKillTime();
        #endif /* (DPWM_KillModeMinTime) */
        
        #if(DPWM_UseControl)
            DPWM_backup.PWMControlRegister = DPWM_ReadControlRegister();
        #endif /* (DPWM_UseControl) */
    #endif  /* (!DPWM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DPWM_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  DPWM_backup:  Variables of this global structure are used to  
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DPWM_RestoreConfig(void) 
{
        #if(!DPWM_UsingFixedFunction)
            #if(!DPWM_PWMModeIsCenterAligned)
                DPWM_WritePeriod(DPWM_backup.PWMPeriod);
            #endif /* (!DPWM_PWMModeIsCenterAligned) */
            DPWM_WriteCounter(DPWM_backup.PWMUdb);
            #if (DPWM_UseStatus)
                DPWM_STATUS_MASK = DPWM_backup.InterruptMaskValue;
            #endif /* (DPWM_UseStatus) */
            
            #if(DPWM_DeadBandMode == DPWM__B_PWM__DBM_256_CLOCKS || \
                DPWM_DeadBandMode == DPWM__B_PWM__DBM_2_4_CLOCKS)
                DPWM_WriteDeadTime(DPWM_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
            #if(DPWM_KillModeMinTime)
                DPWM_WriteKillTime(DPWM_backup.PWMKillCounterPeriod);
            #endif /* (DPWM_KillModeMinTime) */
            
            #if(DPWM_UseControl)
                DPWM_WriteControlRegister(DPWM_backup.PWMControlRegister); 
            #endif /* (DPWM_UseControl) */
        #endif  /* (!DPWM_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DPWM_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  DPWM_backup.PWMEnableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DPWM_Sleep(void) 
{
    #if(DPWM_UseControl)
        if(DPWM_CTRL_ENABLE == (DPWM_CONTROL & DPWM_CTRL_ENABLE))
        {
            /*Component is enabled */
            DPWM_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DPWM_backup.PWMEnableState = 0u;
        }
    #endif /* (DPWM_UseControl) */

    /* Stop component */
    DPWM_Stop();
    
    /* Save registers configuration */
    DPWM_SaveConfig();
}


/*******************************************************************************
* Function Name: DPWM_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  DPWM_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DPWM_Wakeup(void) 
{
     /* Restore registers values */
    DPWM_RestoreConfig();
    
    if(DPWM_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DPWM_Enable();
    } /* Do nothing if component's block was disabled before */
    
}


/* [] END OF FILE */
